package com.qmth.themis.business.service.impl;

import javax.annotation.Resource;

import org.springframework.stereotype.Service;

import com.qmth.themis.business.bean.mobile.MobileAuthorizationBean;
import com.qmth.themis.business.bean.mobile.MobileAuthorizationMonitorBean;
import com.qmth.themis.business.bean.mobile.MobileAuthorizationParamBean;
import com.qmth.themis.business.bean.mobile.MobileAuthorizationUploadBean;
import com.qmth.themis.business.cache.MobileAuthCacheUtil;
import com.qmth.themis.business.enums.MobileModeEnum;
import com.qmth.themis.business.service.TEMobileService;
import com.qmth.themis.business.util.RedisUtil;
import com.qmth.themis.common.enums.Source;
import com.qmth.themis.common.exception.BusinessException;

@Service
public class TEMobileServiceImpl implements TEMobileService {

    @Resource
    RedisUtil redisUtil;
	
	@Override
	public MobileAuthorizationBean authorization(MobileAuthorizationParamBean param) {
		MobileModeEnum mode=param.getMode();
		String code=param.getCode();
		MobileAuthorizationBean ret=null;
		if(MobileModeEnum.MOBILE_MONITOR.equals(mode)) {
			ret=monitorAuthorization(mode, code);
		}else if(MobileModeEnum.PHOTO_UPLOAD.equals(mode)||MobileModeEnum.AUDIO_UPLOAD.equals(mode)) {
			ret=answerUploadAuthorization(mode, code);
		}
		return ret;
	}
	
	private MobileAuthorizationBean monitorAuthorization(MobileModeEnum mode,String code) {
		Long recordId=MobileAuthCacheUtil.getRecordId(mode, code);
		String monitorKey=MobileAuthCacheUtil.getMonitorKey(mode, code);
		Source monitorVideoSource=MobileAuthCacheUtil.getMonitorVideoSource(mode, code);
		Boolean monitorAudioEnable=MobileAuthCacheUtil.getMonitorAudioEnable(mode, code);
		if(MobileAuthCacheUtil.getMode(mode, code)==null) {
			throw new BusinessException("二维码已过期");
		}
		MobileAuthorizationMonitorBean ret=new MobileAuthorizationMonitorBean();
		ret.setRecordId(recordId);
		ret.setMonitorKey(monitorKey);
		ret.setMonitorVideoSource(monitorVideoSource);
		ret.setMonitorAudioEnable(monitorAudioEnable);
		return ret;
	}
	private MobileAuthorizationBean answerUploadAuthorization(MobileModeEnum mode,String code) {
		Long recordId=MobileAuthCacheUtil.getRecordId(mode, code);
		Integer mainNumber=MobileAuthCacheUtil.getMainNumber(mode, code);
		Integer subNumber=MobileAuthCacheUtil.getSubNumber(mode, code);
		Integer subIndex=MobileAuthCacheUtil.getSubIndex(mode, code);
		if(MobileAuthCacheUtil.getMode(mode, code)==null) {
			throw new BusinessException("二维码已过期");
		}
		MobileAuthorizationUploadBean ret=new MobileAuthorizationUploadBean();
		ret.setRecordId(recordId);
		ret.setMainNumber(mainNumber);
		ret.setSubNumber(subNumber);
		ret.setSubIndex(subIndex);
		return ret;
	}
}
